@@ -45,20 +45,25 @@ class TicketInContextWithStateAndVersionView(EntityView):
 class ProjectPatchesTab(EntityView):
     __regid__ = 'vcreview.patches_tab'
     __select__ = is_instance('Project') & score_entity(
-        lambda x: x.source_repository and x.source_repository[0].patchrepo)
+        lambda x: x.source_repository and x.source_repository[0].has_review)
 
     def entity_call(self, entity):
-        entity.source_repository[0].patchrepo.view(
+        entity.source_repository[0].view(
             'vcreview.repository.patches', w=self.w)
 
 
-class PatchRepositoryIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
-    __select__ = is_instance('Repository') & score_entity(lambda x: x.patchrepo_of)
-
-    def parent_entity(self):
-        sourcerepo = self.entity.patchrepo_of
-        return sourcerepo.project or sourcerepo
+class VersionPatchesTab(EntityView):
+    __regid__ = 'trackervcs.version_patches_tab'
+    __select__ = is_instance('Version') & score_entity(
+        lambda x: x.project.source_repository and x.project.source_repository[0].patchrepo)
 
+    def entity_call(self, entity):
+        rql = ('Any P,PO,P,P,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS '
+               'WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
+               'TR? wf_info_for P, RE from_repository R, P patch_ticket T, '
+               'T done_in V, V eid %(v)s')
+        rset = self._cw.execute(rql, {'v': entity.eid})
+        self.wview('vcreview.patches.table', rset, 'noresult')
 
 class HasPatchFacet(facet.HasRelationFacet):
     __regid__ = 'trackervcs.has-patch-facet'
@@ -75,9 +80,10 @@ def registration_callback(vreg):
     if not 'vcreview' in vreg.config.cubes():
         return # don't register anything from this module
 
+    from cubicweb.web.views import tableview
     from cubes.vcreview.views import (startup as vcreview_startup,
                                       primary as vcreview_primary)
-    from cubes.tracker.views import project
+    from cubes.tracker.views import project, version
 
     vreg.register_all(globals().values(), __name__)
 
@@ -85,14 +91,14 @@ def registration_callback(vreg):
     # version
     vcreview_startup.AllActivePatches.rql = (
         'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
-        'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS, '
-        'TR? wf_info_for P, P patch_repository R, R title RT, '
+        'ORDERBY RT,PB,PO WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS, '
+        'TR? wf_info_for P, RE from_repository R, R title RT, '
         'PS name %s, '
         'P patch_ticket T?, T done_in V?')
     vcreview_startup.UserWorkList.rql = (
         'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
-        'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
-        'TR? wf_info_for P, P patch_repository R, R title RT, U eid %(u)s, '
+        'ORDERBY RT,PB,PO WHERE P patch_revision RE, RE author PO, RE branch PB, P in_state PS,'
+        'TR? wf_info_for P, RE from_repository R, R title RT, U eid %(u)s, '
         'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
         'OR EXISTS(PS name "reviewed" AND P patch_committer U) '
         'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer U) '
@@ -100,8 +106,8 @@ def registration_callback(vreg):
         'P patch_ticket T?, T done_in V?')
     vcreview_primary.RepositoryPatchesTable.rql = (
         'Any P,PO,P,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
-        'P originator PO, P branch PB, P in_state PS, TR? wf_info_for P, '
-        'P patch_repository R, R eid %(x)s, '
+        'P patch_revision RE, RE author PO, RE branch PB, P in_state PS, TR? wf_info_for P, '
+        'RE from_repository R, R eid %(x)s, '
         'P patch_ticket T?, T done_in V?')
     # add a tab on project view to display patches
     project.ProjectPrimaryView.tabs.append(ProjectPatchesTab.__regid__)
@@ -112,3 +118,12 @@ def registration_callback(vreg):
     _pvdc.tag_subject_of(('Patch', 'patch_ticket', '*'), {'vid': 'incontext-state-version'})
     _pvs.tag_object_of(('*', 'patch_ticket', 'Ticket'), 'attributes')
     _pvdc.tag_object_of(('*', 'patch_ticket', 'Ticket'), {'vid': 'myincontext-state'})
+
+    project.ProjectTicketsTable.columns.append('patch_ticket')
+    project.ProjectTicketsTable.column_renderers['patch_ticket'] = \
+        tableview.RelationColRenderer(role='object')
+    version.VersionTicketsTable.columns.append('patch_ticket')
+    version.VersionTicketsTable.column_renderers['patch_ticket'] = \
+        tableview.RelationColRenderer(role='object')
+    version.VersionPrimaryView.tabs.append(_('trackervcs.version_patches_tab'))
+
